@@ -6,11 +6,12 @@ from torchquantum.macro import C_DTYPE
 
 __all__ = ['QuantumDevice']
 
-
 class QuantumDevice(nn.Module):
     def __init__(self, n_wires: int):
         super().__init__()
         # number of qubits
+        # the states are represented in a multi-dimension tensor
+        # from left to right: qubit 0 to n
         self.n_wires = n_wires
 
         _state = torch.zeros(2 ** self.n_wires, dtype=C_DTYPE)
@@ -20,6 +21,15 @@ class QuantumDevice(nn.Module):
 
         self.states = None
 
+        self.reset_states(1)
+
+    def clone_states(self, existing_states: torch.Tensor):
+        self.states = existing_states.clone()
+
+    def set_states(self, states: torch.Tensor):
+        bsz = states.shape[0]
+        self.states = torch.reshape(states, [bsz] + [2] * self.n_wires)
+
     def reset_states(self, bsz: int):
         repeat_times = [bsz] + [1] * len(self.state.shape)
         self.states = self.state.repeat(*repeat_times).to(self.state.device)
