@@ -6,10 +6,11 @@ import numpy as np
 
 from enum import IntEnum
 from torchquantum.functional import mat_dict
+from torchquantum.quantization.clifford_quantization import CliffordQuantizer
 from abc import ABCMeta
 from .macro import C_DTYPE, F_DTYPE
 from torchpack.utils.logging import logger
-
+from typing import Iterable, Union, List
 
 __all__ = [
     'op_name_dict',
@@ -18,9 +19,11 @@ __all__ = [
     'DiagonalOperation',
     'Observable',
     'Hadamard',
+    'SHadamard',
     'PauliX',
     'PauliY',
     'PauliZ',
+    'I',
     'S',
     'T',
     'SX',
@@ -30,7 +33,12 @@ __all__ = [
     'RX',
     'RY',
     'RZ',
+    'RXX',
+    'RYY',
+    'RZZ',
+    'RZX',
     'SWAP',
+    'SSWAP',
     'CSWAP',
     'Toffoli',
     'PhaseShift',
@@ -43,27 +51,32 @@ __all__ = [
     'U1',
     'U2',
     'U3',
+    'CU1',
+    'CU2',
+    'CU3',
     'QubitUnitary',
     'QubitUnitaryFast',
     'TrainableUnitary',
     'TrainableUnitaryStrict',
     'MultiCNOT',
     'MultiXCNOT',
+    'Reset',
+    'SingleExcitation',
 ]
 
 
 class WiresEnum(IntEnum):
     """Integer enumeration class
-    to represent the number of wires
-    an operation acts on"""
+        to represent the number of wires
+        an operation acts on."""
     AnyWires = -1
     AllWires = 0
 
 
 class NParamsEnum(IntEnum):
     """Integer enumeration class
-    to represent the number of wires
-    an operation acts on"""
+        to represent the number of wires
+        an operation acts on"""
     AnyNParams = -1
 
 
@@ -80,11 +93,14 @@ subsystem. It is equivalent to an integer with value -1."""
 
 
 class Operator(tq.QuantumModule):
+    """The class for quantum operators."""
     fixed_ops = [
         'Hadamard',
+        'SHadamard',
         'PauliX',
         'PauliY',
         'PauliZ',
+        'I',
         'S',
         'T',
         'SX',
@@ -92,16 +108,22 @@ class Operator(tq.QuantumModule):
         'CZ',
         'CY',
         'SWAP',
+        'SSWAP',
         'CSWAP',
         'Toffoli',
         'MultiCNOT',
         'MultiXCNOT',
+        'Reset',
     ]
 
     parameterized_ops = [
         'RX',
         'RY',
         'RZ',
+        'RXX',
+        'RYY',
+        'RZZ',
+        'RZX',
         'PhaseShift',
         'Rot',
         'MultiRZ',
@@ -112,6 +134,9 @@ class Operator(tq.QuantumModule):
         'U1',
         'U2',
         'U3',
+        'CU1',
+        'CU2',
+        'CU3',
         'QubitUnitary',
         'QubitUnitaryFast',
         'TrainableUnitary',
@@ -125,44 +150,134 @@ class Operator(tq.QuantumModule):
 
     @name.setter
     def name(self, value):
+        """Set the name of the operator.
+
+        Args:
+            value (str): operator name.
+
+        """
         self._name = value
 
-    def __init__(self, wires=None):
+    def __init__(self,
+                 has_params: bool = False,
+                 trainable: bool = False,
+                 init_params=None,
+                 n_wires=None,
+                 wires=None):
+        """__init__ function for Operator.
+
+        Args:
+            has_params (bool, optional): Whether the operations has parameters.
+                Defaults to False.
+            trainable (bool, optional): Whether the parameters are trainable
+                (if contains parameters). Defaults to False.
+            init_params (torch.Tensor, optional): Initial parameters.
+                Defaults to None.
+            n_wires (int, optional): Number of qubits. Defaults to None.
+            wires (Union[int, List[int]], optional): Which qubit the operation
+                is applied to. Defaults to None.
+        """
         super().__init__()
         self.params = None
         # number of wires of the operator
-        self.n_wires = None
+        # n_wires is used in gates that can be applied to arbitrary number
+        # of qubits such as MultiRZ
+        self.n_wires = n_wires
         # wires that the operator applies to
         self.wires = wires
         self._name = self.__class__.__name__
         # for static mode
         self.static_matrix = None
         self.inverse = False
+        self.clifford_quantization = False
+
+        try:
+            assert not (trainable and not has_params)
+        except AssertionError:
+            has_params = True
+            logger.warning(f"Module must have parameters to be trainable; "
+                           f"Switched 'has_params' to True.")
+
+        self.has_params = has_params
+        self.trainable = trainable
+        if self.has_params:
+            self.params = self.build_params(trainable=self.trainable)
+            self.reset_params(init_params)
 
     @classmethod
     def _matrix(cls, params):
+        """The unitary matrix of the operator.
+
+        Args:
+            params (torch.Tensor, optional): The parameters for parameterized
+                operators.
+
+        Returns: None.
+
+        """
         raise NotImplementedError
 
     @property
     def matrix(self):
+        """The unitary matrix of the operator."""
         return self._matrix(self.params)
 
     @classmethod
     def _eigvals(cls, params):
+        """The eigenvalues of the unitary matrix of the operator.
+
+        Args:
+            params (torch.Tensor, optional): The parameters for parameterized
+                operators.
+
+        Returns: None.
+
+        """
         raise NotImplementedError
 
     @property
     def eigvals(self):
+        """The eigenvalues of the unitary matrix of the operator.
+
+        Returns: Eigenvalues.
+
+        """
         return self._eigvals(self.params)
 
     def _get_unitary_matrix(self):
+        """Obtain the unitary matrix of the operator.
+
+        Returns: Unitary matrix.
+
+        """
         return self.matrix
 
     def set_wires(self, wires):
+        """Set which qubits the operator is applied to.
+
+        Args:
+            wires (Union[int, List[int]]): Qubits the operator is applied to.
+
+        Returns: None.
+
+        """
         self.wires = [wires] if isinstance(wires, int) else wires
 
     def forward(self, q_device: tq.QuantumDevice, wires=None, params=None,
                 inverse=False):
+        """Apply the operator to the quantum device states.
+
+        Args:
+            q_device (torchquantum.QuantumDevice): Quantum Device that the
+                operator is applied to.
+            wires (Union[int, List[int]]): Qubits that the operator is
+                applied to.
+            params (torch.Tensor): Parameters of the operator
+            inverse (bool): Whether inverse the unitary matrix of the operator.
+
+        Returns:
+
+        """
         # try:
         #     assert self.name in self.fixed_ops or \
         #            self.has_params ^ (params is not None)
@@ -204,65 +319,133 @@ class Operator(tq.QuantumModule):
                 self.func(q_device, self.wires, n_wires=self.n_wires,
                           inverse=inverse)
         else:
+            if isinstance(self.noise_model_tq, tq.NoiseModelTQPhase):
+                params = self.noise_model_tq.add_noise(self.params)
+            else:
+                params = self.params
+
+            if self.clifford_quantization:
+                params = CliffordQuantizer.quantize_sse(params)
             if self.n_wires is None:
-                self.func(q_device, self.wires, params=self.params,
+                self.func(q_device, self.wires, params=params,
                           inverse=inverse)
             else:
-                self.func(q_device, self.wires, params=self.params,
+                self.func(q_device, self.wires, params=params,
                           n_wires=self.n_wires, inverse=inverse)
 
+        if self.noise_model_tq is not None and \
+                self.noise_model_tq.is_add_noise:
+            noise_ops = self.noise_model_tq.sample_noise_op(self)
+            if len(noise_ops):
+                for noise_op in noise_ops:
+                    noise_op(q_device)
+
 
 class Observable(Operator, metaclass=ABCMeta):
-    def __init__(self, wires=None):
-        super().__init__(wires=wires)
-        self.return_type = None
+    """Class for Observables.
 
-    def diagonalizing_gates(self):
-        raise NotImplementedError
-
-
-class Operation(Operator, metaclass=ABCMeta):
+    """
     def __init__(self,
                  has_params: bool = False,
                  trainable: bool = False,
                  init_params=None,
                  n_wires=None,
                  wires=None):
-        # n_wires is used in gates that can be applied to arbitrary number
-        # of qubits such as MultiRZ
-        super().__init__(wires=wires)
+        """Init function of the Observable class
 
-        try:
-            assert not (trainable and not has_params)
-        except AssertionError:
-            has_params = True
-            logger.warning(f"Module must have parameters to be trainable; "
-                           f"Switched 'has_params' to True.")
+        has_params (bool, optional): Whether the operations has parameters.
+                Defaults to False.
+            trainable (bool, optional): Whether the parameters are trainable
+                (if contains parameters). Defaults to False.
+            init_params (torch.Tensor, optional): Initial parameters.
+                Defaults to None.
+            n_wires (int, optional): Number of qubits. Defaults to None.
+            wires (Union[int, List[int]], optional): Which qubit the operation
+                is applied to. Defaults to None.
+        """
+        super().__init__(
+            has_params=has_params,
+            trainable=trainable,
+            init_params=init_params,
+            n_wires=n_wires,
+            wires=wires
+        )
+        self.return_type = None
 
-        self.has_params = has_params
-        self.trainable = trainable
-        self.n_wires = n_wires
-        self.wires = wires
-        if self.has_params:
-            self.params = self.build_params(trainable=self.trainable)
-            self.reset_params(init_params)
+    def diagonalizing_gates(self):
+        """The diagonalizing gates when perform measurements.
+
+        Returns: None.
+
+        """
+        raise NotImplementedError
+
+
+class Operation(Operator, metaclass=ABCMeta):
+    """_summary_"""
+    def __init__(self,
+                 has_params: bool = False,
+                 trainable: bool = False,
+                 init_params=None,
+                 n_wires=None,
+                 wires=None):
+        """_summary_
+
+        Args:
+            has_params (bool, optional): Whether the operations has parameters.
+                Defaults to False.
+            trainable (bool, optional): Whether the parameters are trainable
+                (if contains parameters). Defaults to False.
+            init_params (torch.Tensor, optional): Initial parameters.
+                Defaults to None.
+            n_wires (int, optional): Number of qubits. Defaults to None.
+            wires (Union[int, List[int]], optional): Which qubit the operation is applied to.
+                Defaults to None.
+        """
+        super().__init__(
+            has_params=has_params,
+            trainable=trainable,
+            init_params=init_params,
+            n_wires=n_wires,
+            wires=wires
+        )
 
     @property
     def matrix(self):
+        """The unitary matrix of the operator."""
         op_matrix = self._matrix(self.params)
 
         return op_matrix
 
     @property
     def eigvals(self):
+        """"The eigenvalues of the unitary matrix of the operator.
+
+        Returns:
+            torch.Tensor: Eigenvalues.
+
+        """
         op_eigvals = self._eigvals(self.params)
 
         return op_eigvals
 
     def init_params(self):
+        """Initialize the parameters.
+
+        Raises:
+            NotImplementedError: The init param function is not implemented.
+        """
         raise NotImplementedError
 
     def build_params(self, trainable):
+        """Build parameters.
+
+        Args:
+            trainable (bool): Whether the parameters are trainable.
+
+        Returns:
+            torch.Tensor: Built parameters.
+        """
         parameters = nn.Parameter(torch.empty([1, self.num_params],
                                               dtype=F_DTYPE))
         parameters.requires_grad = True if trainable else False
@@ -270,31 +453,61 @@ class Operation(Operator, metaclass=ABCMeta):
         return parameters
 
     def reset_params(self, init_params=None):
+        """Reset parameters.
+
+        Args:
+            init_params (torch.Tensor, optional): Input the initialization
+                parameters. Defaults to None.
+        """
         if init_params is not None:
-            if isinstance(init_params, list):
+            if isinstance(init_params, Iterable):
                 for k, init_param in enumerate(init_params):
                     torch.nn.init.constant_(self.params[:, k], init_param)
             else:
                 torch.nn.init.constant_(self.params, init_params)
         else:
-            torch.nn.init.uniform_(self.params, 0, 2 * np.pi)
+            torch.nn.init.uniform_(self.params, -np.pi, np.pi)
 
 
 class DiagonalOperation(Operation, metaclass=ABCMeta):
+    """Class for Diagonal Operation."""
     @classmethod
     def _eigvals(cls, params):
+        """The eigenvalues of the unitary matrix of the operator.
+
+        Args:
+            params (torch.Tensor, optional): The parameters for parameterized
+                operators.
+
+        Returns: None.
         raise NotImplementedError
+    """
 
     @property
     def eigvals(self):
+        """The eigenvalues of the unitary matrix of the operator.
+
+        Returns: Eigenvalues.
+
+        """
         return super().eigvals
 
     @classmethod
     def _matrix(cls, params):
+        """The unitary matrix of the operator.
+
+        Args:
+            params (torch.Tensor, optional): The parameters for parameterized
+                operators.
+
+        Returns: None.
+
+        """
         return torch.diag(cls._eigvals(params))
 
 
-class Hadamard(Observable, Operation, metaclass=ABCMeta):
+class Hadamard(Observable, metaclass=ABCMeta):
+    """Class for Hadamard Gate."""
     num_params = 0
     num_wires = 1
     eigvals = torch.tensor([1, -1], dtype=C_DTYPE)
@@ -315,7 +528,20 @@ class Hadamard(Observable, Operation, metaclass=ABCMeta):
                       init_params=-np.pi / 4)]
 
 
+class SHadamard(Operation, metaclass=ABCMeta):
+    """Class for SHadamard Gate."""
+    num_params = 0
+    num_wires = 1
+    matrix = mat_dict['shadamard']
+    func = staticmethod(tqf.shadamard)
+
+    @classmethod
+    def _matrix(cls, params):
+        return cls.matrix
+
+
 class PauliX(Observable, metaclass=ABCMeta):
+    """Class for Pauli X Gate."""
     num_params = 0
     num_wires = 1
     eigvals = torch.tensor([1, -1], dtype=C_DTYPE)
@@ -335,6 +561,7 @@ class PauliX(Observable, metaclass=ABCMeta):
 
 
 class PauliY(Observable, metaclass=ABCMeta):
+    """Class for Pauli Y Gate."""
     num_params = 0
     num_wires = 1
     eigvals = torch.tensor([1, -1], dtype=C_DTYPE)
@@ -354,6 +581,7 @@ class PauliY(Observable, metaclass=ABCMeta):
 
 
 class PauliZ(Observable, metaclass=ABCMeta):
+    """Class for Pauli Z Gate."""
     num_params = 0
     num_wires = 1
     eigvals = torch.tensor([1, -1], dtype=C_DTYPE)
@@ -372,7 +600,28 @@ class PauliZ(Observable, metaclass=ABCMeta):
         return []
 
 
+class I(Observable, metaclass=ABCMeta):
+    """Class for Identity Gate."""
+    num_params = 0
+    num_wires = 1
+    eigvals = torch.tensor([1, 1], dtype=C_DTYPE)
+    matrix = mat_dict['i']
+    func = staticmethod(tqf.i)
+
+    @classmethod
+    def _matrix(cls, params):
+        return cls.matrix
+
+    @classmethod
+    def _eigvals(cls, params):
+        return cls.eigvals
+
+    def diagonalizing_gates(self):
+        return []
+
+
 class S(DiagonalOperation, metaclass=ABCMeta):
+    """Class for S Gate."""
     num_params = 0
     num_wires = 1
     eigvals = torch.tensor([1, 1j], dtype=C_DTYPE)
@@ -389,6 +638,7 @@ class S(DiagonalOperation, metaclass=ABCMeta):
 
 
 class T(DiagonalOperation, metaclass=ABCMeta):
+    """Class for T Gate."""
     num_params = 0
     num_wires = 1
     eigvals = torch.tensor([1, 1j], dtype=C_DTYPE)
@@ -405,6 +655,7 @@ class T(DiagonalOperation, metaclass=ABCMeta):
 
 
 class SX(Operation, metaclass=ABCMeta):
+    """Class for SX Gate."""
     num_params = 0
     num_wires = 1
     eigvals = torch.tensor([1, 1j], dtype=C_DTYPE)
@@ -421,6 +672,7 @@ class SX(Operation, metaclass=ABCMeta):
 
 
 class CNOT(Operation, metaclass=ABCMeta):
+    """Class for CNOT Gate."""
     num_params = 0
     num_wires = 2
     matrix = mat_dict['cnot']
@@ -432,6 +684,7 @@ class CNOT(Operation, metaclass=ABCMeta):
 
 
 class CZ(DiagonalOperation, metaclass=ABCMeta):
+    """Class for CZ Gate."""
     num_params = 0
     num_wires = 2
     eigvals = np.array([1, 1, 1, -1])
@@ -448,6 +701,7 @@ class CZ(DiagonalOperation, metaclass=ABCMeta):
 
 
 class CY(Operation, metaclass=ABCMeta):
+    """Class for CY Gate."""
     num_params = 0
     num_wires = 2
     matrix = mat_dict['cy']
@@ -459,6 +713,7 @@ class CY(Operation, metaclass=ABCMeta):
 
 
 class SWAP(Operation, metaclass=ABCMeta):
+    """Class for SWAP Gate."""
     num_params = 0
     num_wires = 2
     matrix = mat_dict['swap']
@@ -469,7 +724,20 @@ class SWAP(Operation, metaclass=ABCMeta):
         return cls.matrix
 
 
+class SSWAP(Operation, metaclass=ABCMeta):
+    """Class for SSWAP Gate."""
+    num_params = 0
+    num_wires = 2
+    matrix = mat_dict['sswap']
+    func = staticmethod(tqf.sswap)
+
+    @classmethod
+    def _matrix(cls, params):
+        return cls.matrix
+
+
 class CSWAP(Operation, metaclass=ABCMeta):
+    """Class for CSWAP Gate."""
     num_params = 0
     num_wires = 3
     matrix = mat_dict['cswap']
@@ -481,6 +749,7 @@ class CSWAP(Operation, metaclass=ABCMeta):
 
 
 class Toffoli(Operation, metaclass=ABCMeta):
+    """Class for Toffoli Gate."""
     num_params = 0
     num_wires = 3
     matrix = mat_dict['toffoli']
@@ -492,6 +761,7 @@ class Toffoli(Operation, metaclass=ABCMeta):
 
 
 class RX(Operation, metaclass=ABCMeta):
+    """Class for RX Gate."""
     num_params = 1
     num_wires = 1
     func = staticmethod(tqf.rx)
@@ -502,6 +772,7 @@ class RX(Operation, metaclass=ABCMeta):
 
 
 class RY(Operation, metaclass=ABCMeta):
+    """Class for RY Gate."""
     num_params = 1
     num_wires = 1
     func = staticmethod(tqf.ry)
@@ -512,6 +783,7 @@ class RY(Operation, metaclass=ABCMeta):
 
 
 class RZ(DiagonalOperation, metaclass=ABCMeta):
+    """Class for RZ Gate."""
     num_params = 1
     num_wires = 1
     func = staticmethod(tqf.rz)
@@ -522,6 +794,7 @@ class RZ(DiagonalOperation, metaclass=ABCMeta):
 
 
 class PhaseShift(DiagonalOperation, metaclass=ABCMeta):
+    """Class for PhaseShift Gate."""
     num_params = 1
     num_wires = 1
     func = staticmethod(tqf.phaseshift)
@@ -532,6 +805,7 @@ class PhaseShift(DiagonalOperation, metaclass=ABCMeta):
 
 
 class Rot(Operation, metaclass=ABCMeta):
+    """Class for Rotation Gate."""
     num_params = 3
     num_wires = 1
     func = staticmethod(tqf.rot)
@@ -542,6 +816,7 @@ class Rot(Operation, metaclass=ABCMeta):
 
 
 class MultiRZ(DiagonalOperation, metaclass=ABCMeta):
+    """Class for Multi-qubit RZ Gate."""
     num_params = 1
     num_wires = AnyWires
     func = staticmethod(tqf.multirz)
@@ -551,12 +826,66 @@ class MultiRZ(DiagonalOperation, metaclass=ABCMeta):
         return tqf.multirz_matrix(params, n_wires)
 
 
+class RXX(Operation, metaclass=ABCMeta):
+    """Class for RXX Gate."""
+    num_params = 1
+    num_wires = 2
+    func = staticmethod(tqf.rxx)
+
+    @classmethod
+    def _matrix(cls, params):
+        return tqf.rxx_matrix(params)
+
+
+class RYY(Operation, metaclass=ABCMeta):
+    """Class for RYY Gate."""
+    num_params = 1
+    num_wires = 2
+    func = staticmethod(tqf.ryy)
+
+    @classmethod
+    def _matrix(cls, params):
+        return tqf.ryy_matrix(params)
+
+
+class RZZ(DiagonalOperation, metaclass=ABCMeta):
+    """Class for RZZ Gate."""
+    num_params = 1
+    num_wires = 2
+    func = staticmethod(tqf.rzz)
+
+    @classmethod
+    def _matrix(cls, params):
+        return tqf.rzz_matrix(params)
+
+
+class RZX(Operation, metaclass=ABCMeta):
+    """Class for RZX Gate."""
+    num_params = 1
+    num_wires = 2
+    func = staticmethod(tqf.rzx)
+
+    @classmethod
+    def _matrix(cls, params):
+        return tqf.rzx_matrix(params)
+
+
 class TrainableUnitary(Operation, metaclass=ABCMeta):
+    """Class for TrainableUnitary Gate."""
     num_params = AnyNParams
     num_wires = AnyWires
     func = staticmethod(tqf.qubitunitaryfast)
 
     def build_params(self, trainable):
+        """Build the parameters for the gate.
+
+        Args:
+            trainable (bool): Whether the parameters are trainble.
+
+        Returns:
+            torch.Tensor: Parameters.
+
+        """
         parameters = nn.Parameter(torch.empty(
             1, 2 ** self.n_wires, 2 ** self.n_wires, dtype=C_DTYPE))
         parameters.requires_grad = True if trainable else False
@@ -564,6 +893,15 @@ class TrainableUnitary(Operation, metaclass=ABCMeta):
         return parameters
 
     def reset_params(self, init_params=None):
+        """Reset the parameters.
+
+        Args:
+            init_params (torch.Tensor, optional): Initial parameters.
+
+        Returns:
+            None.
+
+        """
         mat = torch.randn((1, 2 ** self.n_wires, 2 ** self.n_wires),
                           dtype=C_DTYPE)
         U, Sigma, V = torch.svd(mat)
@@ -575,12 +913,14 @@ class TrainableUnitary(Operation, metaclass=ABCMeta):
 
 
 class TrainableUnitaryStrict(TrainableUnitary, metaclass=ABCMeta):
+    """Class for Strict Unitary matrix gate."""
     num_params = AnyNParams
     num_wires = AnyWires
     func = staticmethod(tqf.qubitunitarystrict)
 
 
 class CRX(Operation, metaclass=ABCMeta):
+    """Class for Controlled Rotation X gate."""
     num_params = 1
     num_wires = 2
     func = staticmethod(tqf.crx)
@@ -591,6 +931,7 @@ class CRX(Operation, metaclass=ABCMeta):
 
 
 class CRY(Operation, metaclass=ABCMeta):
+    """Class for Controlled Rotation Y gate."""
     num_params = 1
     num_wires = 2
     func = staticmethod(tqf.cry)
@@ -601,6 +942,7 @@ class CRY(Operation, metaclass=ABCMeta):
 
 
 class CRZ(Operation, metaclass=ABCMeta):
+    """Class for Controlled Rotation Z gate."""
     num_params = 1
     num_wires = 2
     func = staticmethod(tqf.crz)
@@ -611,6 +953,7 @@ class CRZ(Operation, metaclass=ABCMeta):
 
 
 class CRot(Operation, metaclass=ABCMeta):
+    """Class for Controlled Rotation gate."""
     num_params = 3
     num_wires = 2
     func = staticmethod(tqf.crot)
@@ -621,7 +964,9 @@ class CRot(Operation, metaclass=ABCMeta):
 
 
 class U1(DiagonalOperation, metaclass=ABCMeta):
-    # U1 is the same as phaseshift
+    """Class for Controlled Rotation Y gate.  U1 is the same
+        as phaseshift.
+    """
     num_params = 1
     num_wires = 1
     func = staticmethod(tqf.u1)
@@ -631,7 +976,19 @@ class U1(DiagonalOperation, metaclass=ABCMeta):
         return tqf.u1_matrix(params)
 
 
+class CU1(DiagonalOperation, metaclass=ABCMeta):
+    """Class for controlled U1 gate."""
+    num_params = 1
+    num_wires = 2
+    func = staticmethod(tqf.cu1)
+
+    @classmethod
+    def _matrix(cls, params):
+        return tqf.cu1_matrix(params)
+
+
 class U2(Operation, metaclass=ABCMeta):
+    """Class for U2 gate."""
     num_params = 2
     num_wires = 1
     func = staticmethod(tqf.u2)
@@ -641,7 +998,19 @@ class U2(Operation, metaclass=ABCMeta):
         return tqf.u2_matrix(params)
 
 
+class CU2(Operation, metaclass=ABCMeta):
+    """Class for controlled U2 gate."""
+    num_params = 2
+    num_wires = 2
+    func = staticmethod(tqf.cu2)
+
+    @classmethod
+    def _matrix(cls, params):
+        return tqf.cu2_matrix(params)
+
+
 class U3(Operation, metaclass=ABCMeta):
+    """Class for U3 gate."""
     num_params = 3
     num_wires = 1
     func = staticmethod(tqf.u3)
@@ -651,14 +1020,26 @@ class U3(Operation, metaclass=ABCMeta):
         return tqf.u3_matrix(params)
 
 
+class CU3(Operation, metaclass=ABCMeta):
+    """Class for Controlled U3 gate."""
+    num_params = 3
+    num_wires = 2
+    func = staticmethod(tqf.cu3)
+
+    @classmethod
+    def _matrix(cls, params):
+        return tqf.cu3_matrix(params)
+
+
 class QubitUnitary(Operation, metaclass=ABCMeta):
+    """Class for controlled Qubit Unitary gate."""
     num_params = AnyNParams
     num_wires = AnyWires
     func = staticmethod(tqf.qubitunitary)
 
     @classmethod
     def _matrix(cls, params):
-        return tqf.qubitunitary(params)
+        return tqf.qubitunitary_matrix(params)
 
     def build_params(self, trainable):
         return None
@@ -669,13 +1050,15 @@ class QubitUnitary(Operation, metaclass=ABCMeta):
 
 
 class QubitUnitaryFast(Operation, metaclass=ABCMeta):
+    """Class for fast implementation of
+    controlled Qubit Unitary gate."""
     num_params = AnyNParams
     num_wires = AnyWires
     func = staticmethod(tqf.qubitunitaryfast)
 
     @classmethod
     def _matrix(cls, params):
-        return tqf.qubitunitaryfast(params)
+        return tqf.qubitunitaryfast_matrix(params)
 
     def build_params(self, trainable):
         return None
@@ -686,6 +1069,7 @@ class QubitUnitaryFast(Operation, metaclass=ABCMeta):
 
 
 class MultiCNOT(Operation, metaclass=ABCMeta):
+    """Class for Multi qubit CNOT gate."""
     num_params = 0
     num_wires = AnyWires
     func = staticmethod(tqf.multicnot)
@@ -701,6 +1085,7 @@ class MultiCNOT(Operation, metaclass=ABCMeta):
 
 
 class MultiXCNOT(Operation, metaclass=ABCMeta):
+    """Class for Multi qubit XCNOT gate."""
     num_params = 0
     num_wires = AnyWires
     func = staticmethod(tqf.multixcnot)
@@ -715,23 +1100,63 @@ class MultiXCNOT(Operation, metaclass=ABCMeta):
         return op_matrix
 
 
+class Reset(Operator, metaclass=ABCMeta):
+    """Class for Reset gate."""
+    num_params = 0
+    num_wires = AnyWires
+    func = staticmethod(tqf.reset)
+
+    @classmethod
+    def _matrix(cls, params):
+        return None
+
+
+class SingleExcitation(Operator, metaclass=ABCMeta):
+    """Class for SingleExcitation gate."""
+    num_params = 1
+    num_wires = 2
+    func = staticmethod(tqf.single_excitation)
+
+    @classmethod
+    def _matrix(cls, params):
+        return tqf.single_excitation_matrix(params)
+
+
 op_name_dict = {
     'hadamard': Hadamard,
+    'h': Hadamard,
+    'shadamard': SHadamard,
+    'sh': SHadamard,
     'paulix': PauliX,
+    'x': PauliX,
     'pauliy': PauliY,
+    'y': PauliY,
     'pauliz': PauliZ,
+    'z': PauliZ,
+    'i': I,
     's': S,
     't': T,
     'sx': SX,
+    'cx': CNOT,
     'cnot': CNOT,
     'cz': CZ,
     'cy': CY,
     'rx': RX,
     'ry': RY,
     'rz': RZ,
+    'rxx': RXX,
+    'xx': RXX,
+    'ryy': RYY,
+    'yy': RYY,
+    'rzz': RZZ,
+    'zz': RZZ,
+    'rzx': RZX,
+    'zx': RZX,
     'swap': SWAP,
+    'sswap': SSWAP,
     'cswap': CSWAP,
     'toffoli': Toffoli,
+    'ccx': Toffoli,
     'phaseshift': PhaseShift,
     'rot': Rot,
     'multirz': MultiRZ,
@@ -740,8 +1165,17 @@ op_name_dict = {
     'crz': CRZ,
     'crot': CRot,
     'u1': U1,
+    'p': U1,
     'u2': U2,
     'u3': U3,
+    'u': U3,
+    'cu1': CU1,
+    'cp': CU1,
+    'cr': CU1,
+    'cphase': CU1,
+    'cu2': CU2,
+    'cu3': CU3,
+    'cu': CU3,
     'qubitunitary': QubitUnitary,
     'qubitunitarystrict': QubitUnitaryFast,
     'qubitunitaryfast': QubitUnitaryFast,
@@ -749,4 +1183,5 @@ op_name_dict = {
     'trainableunitarystrict': TrainableUnitaryStrict,
     'multicnot': MultiCNOT,
     'multixcnot': MultiXCNOT,
+    'reset': Reset,
 }
